@@ -3,10 +3,7 @@
 
 from trytond.pool import Pool
 
-from . import payment
-from . import party
-from . import routes
-from . import ir
+from . import ir, party, payment, routes
 
 __all__ = ['register', 'routes']
 
@@ -16,11 +13,14 @@ def register():
         payment.Account,
         payment.Refund,
         payment.Customer,
+        payment.CustomerFingerprint,
+        payment.CustomerIdentical,
         payment.Journal,
         payment.Group,
         payment.Payment,
         payment.CustomerSourceDetachAsk,
         party.Party,
+        party.PartyReceptionDirectDebit,
         ir.Cron,
         module='account_payment_stripe', type_='model')
     Pool.register(
